/* -*- indent-tabs-mode: t; tab-width: 4; c-basic-offset: 4; -*- */
/*
   log.c
   liblats library

   (C) Copyright 2007 Olivier Delhomme
   e-mail : olivier.delhomme@interieur.gouv.fr
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.           
*/

#include "lats.h"

static void my_log(log_t * log, GLogLevelFlags log_level, const char *format, ...);

/**
 *
 */
static void my_log(log_t * log, GLogLevelFlags log_level, const char *format, ...)
{
	va_list args;
	gchar *str = NULL;
	gchar *display = NULL;
	GtkTextBuffer *tb = NULL;
	GtkTextIter iStart;

	va_start(args, format);
	str = g_strdup_vprintf(format, args);
	va_end(args);

	switch (log_level)
		{
		case G_LOG_FLAG_RECURSION:
			display = g_strdup_printf("%s - RECURSION: %s\n%c", log->log_domain, str, '\0');
			g_print("%s\n", display);
			exit(log_level);
			break;
 
		case G_LOG_FLAG_FATAL:
			display = g_strdup_printf("%s - FATAL: %s\n%c", log->log_domain, str, '\0');
			g_print("%s\n", display);
			exit(log_level);
			break;

		case G_LOG_LEVEL_ERROR:
			display = g_strdup_printf("%s - ERROR: %s\n%c", log->log_domain, str, '\0');
			g_print("%s\n", display);
			exit(log_level);
			break;

		case G_LOG_LEVEL_CRITICAL:
			display = g_strdup_printf("%s - CRITICAL: %s\n%c", log->log_domain, str, '\0');
			break;

		case G_LOG_LEVEL_WARNING:
			display = g_strdup_printf("%s - WARNING: %s\n%c", log->log_domain, str, '\0');
			break;

		case G_LOG_LEVEL_MESSAGE:
			display = g_strdup_printf("%s - MESSAGE: %s\n%c", log->log_domain, str, '\0');
			break;

		case G_LOG_LEVEL_INFO:
			display = g_strdup_printf("%s - INFO: %s\n%c", log->log_domain, str, '\0');
			break;

		case G_LOG_LEVEL_DEBUG:
			display = g_strdup_printf("%s - DEBUG: %s\n%c", log->log_domain, str, '\0');
			break;

		case G_LOG_LEVEL_MASK: /* Pour viter un warning  la compilation */
			break;
		}

	g_print("%s", display);
	tb = GTK_TEXT_BUFFER(gtk_text_view_get_buffer(GTK_TEXT_VIEW(log->textview)));
	gtk_text_buffer_get_end_iter(tb, &iStart);
	gtk_text_buffer_insert(tb, &iStart, display, -1);
	
	g_free(str);
	g_free(display);
}

/* Fonction permettant de loguer un message en fonction de son niveau */
void log_message(log_t * log, GLogLevelFlags log_level, const char *format, ...)
{
	va_list args;
	gchar *str = NULL;
	gchar *str_time = NULL;
	gchar *str_time_utf8 = NULL;
	gchar *str_utf8 = NULL;
	GTimeVal *time = NULL;
	GError *err = NULL;

	g_return_if_fail (format != NULL);

	va_start(args, format);
	str = g_strdup_vprintf(format, args);
	va_end(args);
	
	time = (GTimeVal *) g_malloc0 (sizeof(GTimeVal));
	g_get_current_time(time);
	str_time = g_time_val_to_iso8601(time);
	str_time_utf8 = g_locale_to_utf8(str_time, -1, NULL, NULL, &err);
	str_utf8 = g_locale_to_utf8(str, -1, NULL, NULL, &err);

	if (str_utf8)
		{
			if (str_time_utf8)
				my_log(log, log_level, "%s - %s%c", str_time_utf8, str_utf8, '\0');
			else
				my_log(log, log_level, "%s - %s%c", str_time, str_utf8, '\0');
		}
	else
		{
			if (str_time_utf8)
				my_log(log, log_level, "%s - %s%c", str_time_utf8, str, '\0');
			else
				my_log(log, log_level, "%s - %s%c", str_time, str, '\0');
		}

	g_free(time);
	g_free(str);
	g_free(str_time);
	g_free(str_time_utf8);
	g_free(str_utf8);
}


extern log_t *init_log_domain(GtkTextView *textview, gchar *log_domain)
{
  log_t *log = NULL;

  log = (log_t *) g_malloc0 (sizeof(log_t));

  log->textview = textview;
  log->log_domain = log_domain;

  return log;

}
